# coding: utf-8

# flake8: noqa
"""
    prediction-api

    An API that predicts skills based on job titles and provided skill sets.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.prediction.models.bad_request import BadRequest
from phenom.api.prediction.models.error_response import ErrorResponse
from phenom.api.prediction.models.skill_prediction_request import SkillPredictionRequest
from phenom.api.prediction.models.skill_prediction_response import SkillPredictionResponse
from phenom.api.prediction.models.skill_result import SkillResult
from phenom.api.prediction.models.skill_results import SkillResults
