# coding: utf-8

"""
    jobs-activities-api

    These API's allows you to perform activities on Jobs  # noqa: E501

    OpenAPI spec version: 1.0.3
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetJobAttachmentsResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attachment_date': 'str',
        'created_by_user_name': 'str',
        'attachment_name': 'str',
        'attachment_id': 'str',
        'created_by_user_email': 'str'
    }

    attribute_map = {
        'attachment_date': 'attachmentDate',
        'created_by_user_name': 'createdByUserName',
        'attachment_name': 'attachmentName',
        'attachment_id': 'attachmentId',
        'created_by_user_email': 'createdByUserEmail'
    }

    def __init__(self, attachment_date=None, created_by_user_name=None, attachment_name=None, attachment_id=None, created_by_user_email=None):  # noqa: E501
        """GetJobAttachmentsResponseData - a model defined in Swagger"""  # noqa: E501
        self._attachment_date = None
        self._created_by_user_name = None
        self._attachment_name = None
        self._attachment_id = None
        self._created_by_user_email = None
        self.discriminator = None
        self.attachment_date = attachment_date
        self.created_by_user_name = created_by_user_name
        self.attachment_name = attachment_name
        self.attachment_id = attachment_id
        self.created_by_user_email = created_by_user_email

    @property
    def attachment_date(self):
        """Gets the attachment_date of this GetJobAttachmentsResponseData.  # noqa: E501


        :return: The attachment_date of this GetJobAttachmentsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._attachment_date

    @attachment_date.setter
    def attachment_date(self, attachment_date):
        """Sets the attachment_date of this GetJobAttachmentsResponseData.


        :param attachment_date: The attachment_date of this GetJobAttachmentsResponseData.  # noqa: E501
        :type: str
        """
        if attachment_date is None:
            raise ValueError("Invalid value for `attachment_date`, must not be `None`")  # noqa: E501

        self._attachment_date = attachment_date

    @property
    def created_by_user_name(self):
        """Gets the created_by_user_name of this GetJobAttachmentsResponseData.  # noqa: E501


        :return: The created_by_user_name of this GetJobAttachmentsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_by_user_name

    @created_by_user_name.setter
    def created_by_user_name(self, created_by_user_name):
        """Sets the created_by_user_name of this GetJobAttachmentsResponseData.


        :param created_by_user_name: The created_by_user_name of this GetJobAttachmentsResponseData.  # noqa: E501
        :type: str
        """
        if created_by_user_name is None:
            raise ValueError("Invalid value for `created_by_user_name`, must not be `None`")  # noqa: E501

        self._created_by_user_name = created_by_user_name

    @property
    def attachment_name(self):
        """Gets the attachment_name of this GetJobAttachmentsResponseData.  # noqa: E501


        :return: The attachment_name of this GetJobAttachmentsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._attachment_name

    @attachment_name.setter
    def attachment_name(self, attachment_name):
        """Sets the attachment_name of this GetJobAttachmentsResponseData.


        :param attachment_name: The attachment_name of this GetJobAttachmentsResponseData.  # noqa: E501
        :type: str
        """
        if attachment_name is None:
            raise ValueError("Invalid value for `attachment_name`, must not be `None`")  # noqa: E501

        self._attachment_name = attachment_name

    @property
    def attachment_id(self):
        """Gets the attachment_id of this GetJobAttachmentsResponseData.  # noqa: E501


        :return: The attachment_id of this GetJobAttachmentsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this GetJobAttachmentsResponseData.


        :param attachment_id: The attachment_id of this GetJobAttachmentsResponseData.  # noqa: E501
        :type: str
        """
        if attachment_id is None:
            raise ValueError("Invalid value for `attachment_id`, must not be `None`")  # noqa: E501

        self._attachment_id = attachment_id

    @property
    def created_by_user_email(self):
        """Gets the created_by_user_email of this GetJobAttachmentsResponseData.  # noqa: E501


        :return: The created_by_user_email of this GetJobAttachmentsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_by_user_email

    @created_by_user_email.setter
    def created_by_user_email(self, created_by_user_email):
        """Sets the created_by_user_email of this GetJobAttachmentsResponseData.


        :param created_by_user_email: The created_by_user_email of this GetJobAttachmentsResponseData.  # noqa: E501
        :type: str
        """
        if created_by_user_email is None:
            raise ValueError("Invalid value for `created_by_user_email`, must not be `None`")  # noqa: E501

        self._created_by_user_email = created_by_user_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetJobAttachmentsResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetJobAttachmentsResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
