# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetWorkflowResponseUpdatedByRecruiterInfo(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recruiter_user_id': 'str'
    }

    attribute_map = {
        'recruiter_user_id': 'recruiterUserId'
    }

    def __init__(self, recruiter_user_id=None):  # noqa: E501
        """GetWorkflowResponseUpdatedByRecruiterInfo - a model defined in Swagger"""  # noqa: E501
        self._recruiter_user_id = None
        self.discriminator = None
        self.recruiter_user_id = recruiter_user_id

    @property
    def recruiter_user_id(self):
        """Gets the recruiter_user_id of this GetWorkflowResponseUpdatedByRecruiterInfo.  # noqa: E501

        ID of the recruiter who last updated the workflow.  # noqa: E501

        :return: The recruiter_user_id of this GetWorkflowResponseUpdatedByRecruiterInfo.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_user_id

    @recruiter_user_id.setter
    def recruiter_user_id(self, recruiter_user_id):
        """Sets the recruiter_user_id of this GetWorkflowResponseUpdatedByRecruiterInfo.

        ID of the recruiter who last updated the workflow.  # noqa: E501

        :param recruiter_user_id: The recruiter_user_id of this GetWorkflowResponseUpdatedByRecruiterInfo.  # noqa: E501
        :type: str
        """
        if recruiter_user_id is None:
            raise ValueError("Invalid value for `recruiter_user_id`, must not be `None`")  # noqa: E501

        self._recruiter_user_id = recruiter_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetWorkflowResponseUpdatedByRecruiterInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetWorkflowResponseUpdatedByRecruiterInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
