# coding: utf-8

# flake8: noqa

"""
    candidates-attachments-api

    The Candidate APIs allows you to add, update and delete candidate attachments.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.candidatesAttachmentsApi.candidate_attachments_api import CandidateAttachmentsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.candidatesAttachmentsApi.models.add_attachments_request import AddAttachmentsRequest
from phenom.api.candidatesAttachmentsApi.models.attachment import Attachment
from phenom.api.candidatesAttachmentsApi.models.attachment_attachments import AttachmentAttachments
from phenom.api.candidatesAttachmentsApi.models.attachment_update_response import AttachmentUpdateResponse
from phenom.api.candidatesAttachmentsApi.models.delete_attachment_request import DeleteAttachmentRequest
from phenom.api.candidatesAttachmentsApi.models.delete_attachment_request_attachments import DeleteAttachmentRequestAttachments
from phenom.api.candidatesAttachmentsApi.models.error import Error
from phenom.api.candidatesAttachmentsApi.models.error_message import ErrorMessage
from phenom.api.candidatesAttachmentsApi.models.pre_signed_url import PreSignedUrl
