# coding: utf-8

# flake8: noqa
"""
    employees-api-courses

    The Employee course APIs are related to the courses that an employee can use them for upskilling in an organisation.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.employeescourses.models.bad_request import BadRequest
from phenom.api.employeescourses.models.course import Course
from phenom.api.employeescourses.models.courses_success_response import CoursesSuccessResponse
from phenom.api.employeescourses.models.courses_success_response_with_data import CoursesSuccessResponseWithData
from phenom.api.employeescourses.models.create_course import CreateCourse
from phenom.api.employeescourses.models.error_response import ErrorResponse
from phenom.api.employeescourses.models.get_all_saved_courses import GetAllSavedCourses
from phenom.api.employeescourses.models.get_all_saved_courses_data import GetAllSavedCoursesData
from phenom.api.employeescourses.models.get_all_saved_courses_data_default import GetAllSavedCoursesDataDefault
from phenom.api.employeescourses.models.get_completed_courses_data import GetCompletedCoursesData
from phenom.api.employeescourses.models.save_course import SaveCourse
from phenom.api.employeescourses.models.un_save_course import UnSaveCourse
from phenom.api.employeescourses.models.update_course import UpdateCourse
from phenom.api.employeescourses.models.update_course_status import UpdateCourseStatus
