# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CreateProjectRequestHiringTeamList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'email_id': 'str',
        'type': 'str',
        'role': 'str',
        'id': 'str'
    }

    attribute_map = {
        'name': 'name',
        'email_id': 'emailId',
        'type': 'type',
        'role': 'role',
        'id': 'id'
    }

    def __init__(self, name=None, email_id=None, type=None, role=None, id=None):  # noqa: E501
        """CreateProjectRequestHiringTeamList - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._email_id = None
        self._type = None
        self._role = None
        self._id = None
        self.discriminator = None
        self.name = name
        self.email_id = email_id
        self.type = type
        self.role = role
        self.id = id

    @property
    def name(self):
        """Gets the name of this CreateProjectRequestHiringTeamList.  # noqa: E501

        Name of the team member.  # noqa: E501

        :return: The name of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateProjectRequestHiringTeamList.

        Name of the team member.  # noqa: E501

        :param name: The name of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def email_id(self):
        """Gets the email_id of this CreateProjectRequestHiringTeamList.  # noqa: E501

        Email ID of the team member.  # noqa: E501

        :return: The email_id of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this CreateProjectRequestHiringTeamList.

        Email ID of the team member.  # noqa: E501

        :param email_id: The email_id of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :type: str
        """
        if email_id is None:
            raise ValueError("Invalid value for `email_id`, must not be `None`")  # noqa: E501

        self._email_id = email_id

    @property
    def type(self):
        """Gets the type of this CreateProjectRequestHiringTeamList.  # noqa: E501

        Type of the team member.  # noqa: E501

        :return: The type of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateProjectRequestHiringTeamList.

        Type of the team member.  # noqa: E501

        :param type: The type of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def role(self):
        """Gets the role of this CreateProjectRequestHiringTeamList.  # noqa: E501

        Role of the team member.  # noqa: E501

        :return: The role of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this CreateProjectRequestHiringTeamList.

        Role of the team member.  # noqa: E501

        :param role: The role of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :type: str
        """
        if role is None:
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501

        self._role = role

    @property
    def id(self):
        """Gets the id of this CreateProjectRequestHiringTeamList.  # noqa: E501

        ID of the team member.  # noqa: E501

        :return: The id of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CreateProjectRequestHiringTeamList.

        ID of the team member.  # noqa: E501

        :param id: The id of this CreateProjectRequestHiringTeamList.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateProjectRequestHiringTeamList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateProjectRequestHiringTeamList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
