# coding: utf-8

# flake8: noqa

"""
    employees-api-referral

    The employee referral APIs are used to refer, track and recommend jobs to external candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.employeesreferral.employee_referrals_api import EmployeeReferralsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.employeesreferral.models.bad_request import BadRequest
from phenom.api.employeesreferral.models.create_employee_referral import CreateEmployeeReferral
from phenom.api.employeesreferral.models.create_employee_referral_questionnaire import CreateEmployeeReferralQuestionnaire
from phenom.api.employeesreferral.models.empty import Empty
from phenom.api.employeesreferral.models.error_response import ErrorResponse
from phenom.api.employeesreferral.models.get_employee_referral_success_response import GetEmployeeReferralSuccessResponse
from phenom.api.employeesreferral.models.get_employee_referral_success_response_candidates import GetEmployeeReferralSuccessResponseCandidates
from phenom.api.employeesreferral.models.get_referral_questionnaire_response import GetReferralQuestionnaireResponse
from phenom.api.employeesreferral.models.get_referral_recommendations_response import GetReferralRecommendationsResponse
from phenom.api.employeesreferral.models.get_referral_recommendations_with_resume import GetReferralRecommendationsWithResume
from phenom.api.employeesreferral.models.job_recommendations import JobRecommendations
from phenom.api.employeesreferral.models.questionnaire import Questionnaire
from phenom.api.employeesreferral.models.referral_data import ReferralData
from phenom.api.employeesreferral.models.referral_data_questionnaire import ReferralDataQuestionnaire
from phenom.api.employeesreferral.models.referral_success_response import ReferralSuccessResponse
