# coding: utf-8

# flake8: noqa

"""
    candidates-api-activities

    The Note APIs allows you to Add, Get, Update and Delete Notes.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.candidatesapiactivities.candidate_activities_api import CandidateActivitiesApi
from phenom.api.candidatesapiactivities.candidate_notes_api import CandidateNotesApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.candidatesapiactivities.models.add_notes import AddNotes
from phenom.api.candidatesapiactivities.models.bad_request import BadRequest
from phenom.api.candidatesapiactivities.models.bad_request_error import BadRequestError
from phenom.api.candidatesapiactivities.models.bad_request_error_errors import BadRequestErrorErrors
from phenom.api.candidatesapiactivities.models.create_note_success import CreateNoteSuccess
from phenom.api.candidatesapiactivities.models.delete_note_success import DeleteNoteSuccess
from phenom.api.candidatesapiactivities.models.error import Error
from phenom.api.candidatesapiactivities.models.fetch_candidate_notes import FetchCandidateNotes
from phenom.api.candidatesapiactivities.models.fetch_candidate_notes_data import FetchCandidateNotesData
from phenom.api.candidatesapiactivities.models.fetch_candidate_notes_pagination import FetchCandidateNotesPagination
from phenom.api.candidatesapiactivities.models.forbidden_error import ForbiddenError
from phenom.api.candidatesapiactivities.models.get_candidate_job_notes import GetCandidateJobNotes
from phenom.api.candidatesapiactivities.models.get_candidate_job_notes_data import GetCandidateJobNotesData
from phenom.api.candidatesapiactivities.models.get_note_activities import GetNoteActivities
from phenom.api.candidatesapiactivities.models.get_note_activities_data import GetNoteActivitiesData
from phenom.api.candidatesapiactivities.models.get_note_activities_pagination import GetNoteActivitiesPagination
from phenom.api.candidatesapiactivities.models.get_note_activities_scope_attr import GetNoteActivitiesScopeAttr
from phenom.api.candidatesapiactivities.models.internal_server_error import InternalServerError
from phenom.api.candidatesapiactivities.models.internal_server_error_response import InternalServerErrorResponse
from phenom.api.candidatesapiactivities.models.no_content_response import NoContentResponse
from phenom.api.candidatesapiactivities.models.not_found_error import NotFoundError
from phenom.api.candidatesapiactivities.models.profile_action_activities import ProfileActionActivities
from phenom.api.candidatesapiactivities.models.profile_action_activities_data import ProfileActionActivitiesData
from phenom.api.candidatesapiactivities.models.profile_action_activities_pagination import ProfileActionActivitiesPagination
from phenom.api.candidatesapiactivities.models.profile_update_activities import ProfileUpdateActivities
from phenom.api.candidatesapiactivities.models.profile_update_activities_data import ProfileUpdateActivitiesData
from phenom.api.candidatesapiactivities.models.profile_update_activities_pagination import ProfileUpdateActivitiesPagination
from phenom.api.candidatesapiactivities.models.success_response import SuccessResponse
from phenom.api.candidatesapiactivities.models.unauthorized_request import UnauthorizedRequest
from phenom.api.candidatesapiactivities.models.update_candidate_note import UpdateCandidateNote
