# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class AwardDataAwards(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'field_id': 'str',
        'description': 'str',
        'title': 'str',
        'awarded_on': 'AwardDataAwardedOn',
        'valid': 'bool'
    }

    attribute_map = {
        'field_id': 'fieldID',
        'description': 'description',
        'title': 'title',
        'awarded_on': 'awardedOn',
        'valid': 'valid'
    }

    def __init__(self, field_id=None, description=None, title=None, awarded_on=None, valid=None):  # noqa: E501
        """AwardDataAwards - a model defined in Swagger"""  # noqa: E501
        self._field_id = None
        self._description = None
        self._title = None
        self._awarded_on = None
        self._valid = None
        self.discriminator = None
        if field_id is not None:
            self.field_id = field_id
        if description is not None:
            self.description = description
        if title is not None:
            self.title = title
        if awarded_on is not None:
            self.awarded_on = awarded_on
        if valid is not None:
            self.valid = valid

    @property
    def field_id(self):
        """Gets the field_id of this AwardDataAwards.  # noqa: E501

        Unique identifier for the award field.  # noqa: E501

        :return: The field_id of this AwardDataAwards.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this AwardDataAwards.

        Unique identifier for the award field.  # noqa: E501

        :param field_id: The field_id of this AwardDataAwards.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def description(self):
        """Gets the description of this AwardDataAwards.  # noqa: E501

        Description of the award.  # noqa: E501

        :return: The description of this AwardDataAwards.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this AwardDataAwards.

        Description of the award.  # noqa: E501

        :param description: The description of this AwardDataAwards.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def title(self):
        """Gets the title of this AwardDataAwards.  # noqa: E501

        Title of the award.  # noqa: E501

        :return: The title of this AwardDataAwards.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this AwardDataAwards.

        Title of the award.  # noqa: E501

        :param title: The title of this AwardDataAwards.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def awarded_on(self):
        """Gets the awarded_on of this AwardDataAwards.  # noqa: E501


        :return: The awarded_on of this AwardDataAwards.  # noqa: E501
        :rtype: AwardDataAwardedOn
        """
        return self._awarded_on

    @awarded_on.setter
    def awarded_on(self, awarded_on):
        """Sets the awarded_on of this AwardDataAwards.


        :param awarded_on: The awarded_on of this AwardDataAwards.  # noqa: E501
        :type: AwardDataAwardedOn
        """

        self._awarded_on = awarded_on

    @property
    def valid(self):
        """Gets the valid of this AwardDataAwards.  # noqa: E501

        Indicator of the award validity.  # noqa: E501

        :return: The valid of this AwardDataAwards.  # noqa: E501
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """Sets the valid of this AwardDataAwards.

        Indicator of the award validity.  # noqa: E501

        :param valid: The valid of this AwardDataAwards.  # noqa: E501
        :type: bool
        """

        self._valid = valid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AwardDataAwards, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AwardDataAwards):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
