# coding: utf-8

"""
    resume-parser-api

    The Resume Parser extracts important information of a candidate such as candidate's name, contact information, email id, education, work experience, and skills, etc. from the resume using Deep learning models.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ResumeResponseDataResumedataEducationhistory(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'school': 'str',
        'city': 'str',
        'state': 'str',
        'country': 'str',
        'degree': 'str',
        'startdate': 'str',
        'enddate': 'str',
        'aggregate': 'str'
    }

    attribute_map = {
        'school': 'school',
        'city': 'city',
        'state': 'state',
        'country': 'country',
        'degree': 'degree',
        'startdate': 'startdate',
        'enddate': 'enddate',
        'aggregate': 'aggregate'
    }

    def __init__(self, school=None, city=None, state=None, country=None, degree=None, startdate=None, enddate=None, aggregate=None):  # noqa: E501
        """ResumeResponseDataResumedataEducationhistory - a model defined in Swagger"""  # noqa: E501
        self._school = None
        self._city = None
        self._state = None
        self._country = None
        self._degree = None
        self._startdate = None
        self._enddate = None
        self._aggregate = None
        self.discriminator = None
        if school is not None:
            self.school = school
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if degree is not None:
            self.degree = degree
        if startdate is not None:
            self.startdate = startdate
        if enddate is not None:
            self.enddate = enddate
        if aggregate is not None:
            self.aggregate = aggregate

    @property
    def school(self):
        """Gets the school of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        College name.  # noqa: E501

        :return: The school of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._school

    @school.setter
    def school(self, school):
        """Sets the school of this ResumeResponseDataResumedataEducationhistory.

        College name.  # noqa: E501

        :param school: The school of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._school = school

    @property
    def city(self):
        """Gets the city of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        City.  # noqa: E501

        :return: The city of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this ResumeResponseDataResumedataEducationhistory.

        City.  # noqa: E501

        :param city: The city of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        state  # noqa: E501

        :return: The state of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ResumeResponseDataResumedataEducationhistory.

        state  # noqa: E501

        :param state: The state of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        Country.  # noqa: E501

        :return: The country of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this ResumeResponseDataResumedataEducationhistory.

        Country.  # noqa: E501

        :param country: The country of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def degree(self):
        """Gets the degree of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        Degree.  # noqa: E501

        :return: The degree of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._degree

    @degree.setter
    def degree(self, degree):
        """Sets the degree of this ResumeResponseDataResumedataEducationhistory.

        Degree.  # noqa: E501

        :param degree: The degree of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._degree = degree

    @property
    def startdate(self):
        """Gets the startdate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        Joining date.  # noqa: E501

        :return: The startdate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._startdate

    @startdate.setter
    def startdate(self, startdate):
        """Sets the startdate of this ResumeResponseDataResumedataEducationhistory.

        Joining date.  # noqa: E501

        :param startdate: The startdate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._startdate = startdate

    @property
    def enddate(self):
        """Gets the enddate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        End date.  # noqa: E501

        :return: The enddate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._enddate

    @enddate.setter
    def enddate(self, enddate):
        """Sets the enddate of this ResumeResponseDataResumedataEducationhistory.

        End date.  # noqa: E501

        :param enddate: The enddate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._enddate = enddate

    @property
    def aggregate(self):
        """Gets the aggregate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501

        Aggregate values.  # noqa: E501

        :return: The aggregate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :rtype: str
        """
        return self._aggregate

    @aggregate.setter
    def aggregate(self, aggregate):
        """Sets the aggregate of this ResumeResponseDataResumedataEducationhistory.

        Aggregate values.  # noqa: E501

        :param aggregate: The aggregate of this ResumeResponseDataResumedataEducationhistory.  # noqa: E501
        :type: str
        """

        self._aggregate = aggregate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResumeResponseDataResumedataEducationhistory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResumeResponseDataResumedataEducationhistory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
