# coding: utf-8

# flake8: noqa
"""
    campaigns-email

    These APIs ensures an easy integration process of Email management for developers to send, read, and track Email campaigns within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.campaignsemail.models.api_error import ApiError
from phenom.api.campaignsemail.models.api_link import ApiLink
from phenom.api.campaignsemail.models.bad_request import BadRequest
from phenom.api.campaignsemail.models.email_campaign_activity import EmailCampaignActivity
from phenom.api.campaignsemail.models.email_campaign_activity_data import EmailCampaignActivityData
from phenom.api.campaignsemail.models.email_campaign_activity_pagination import EmailCampaignActivityPagination
from phenom.api.campaignsemail.models.email_campaign_history import EmailCampaignHistory
from phenom.api.campaignsemail.models.email_campaign_history_data import EmailCampaignHistoryData
from phenom.api.campaignsemail.models.email_campaign_history_pagination import EmailCampaignHistoryPagination
from phenom.api.campaignsemail.models.email_campaign_opt_in import EmailCampaignOptIn
from phenom.api.campaignsemail.models.email_campaign_opt_in_details import EmailCampaignOptInDetails
from phenom.api.campaignsemail.models.email_campaign_opt_in_history import EmailCampaignOptInHistory
from phenom.api.campaignsemail.models.email_campaign_opt_in_history_details import EmailCampaignOptInHistoryDetails
from phenom.api.campaignsemail.models.email_campaign_opt_in_history_details_content import EmailCampaignOptInHistoryDetailsContent
from phenom.api.campaignsemail.models.email_campaign_opt_in_history_details_pageable import EmailCampaignOptInHistoryDetailsPageable
from phenom.api.campaignsemail.models.email_campaign_opt_in_history_details_pageable_sort import EmailCampaignOptInHistoryDetailsPageableSort
from phenom.api.campaignsemail.models.email_campaign_opt_in_request import EmailCampaignOptInRequest
from phenom.api.campaignsemail.models.email_campaign_opt_in_response import EmailCampaignOptInResponse
from phenom.api.campaignsemail.models.email_campaign_opt_in_response_details import EmailCampaignOptInResponseDetails
from phenom.api.campaignsemail.models.internal_server_error import InternalServerError
from phenom.api.campaignsemail.models.send_email_campaign_request import SendEmailCampaignRequest
from phenom.api.campaignsemail.models.send_email_campaign_response import SendEmailCampaignResponse
from phenom.api.campaignsemail.models.send_email_campaign_response_data import SendEmailCampaignResponseData
from phenom.api.campaignsemail.models.unauthorized_request import UnauthorizedRequest
