# coding: utf-8

# flake8: noqa

"""
    recommendations-api

    These APIs provide job suggestions based on your profile, akin job listings, and nearby job opportunities tailored to your qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.recommendation.recommendations_api import RecommendationsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.recommendation.models.bad_request import BadRequest
from phenom.api.recommendation.models.error_response import ErrorResponse
from phenom.api.recommendation.models.job_node import JobNode
from phenom.api.recommendation.models.job_recommendation import JobRecommendation
from phenom.api.recommendation.models.near_by_jobs_response import NearByJobsResponse
from phenom.api.recommendation.models.near_by_jobs_response_data import NearByJobsResponseData
from phenom.api.recommendation.models.preferred_locations import PreferredLocations
from phenom.api.recommendation.models.preferred_locations_latlong import PreferredLocationsLatlong
from phenom.api.recommendation.models.profile_matching_response import ProfileMatchingResponse
from phenom.api.recommendation.models.profile_matching_response_jobs import ProfileMatchingResponseJobs
from phenom.api.recommendation.models.profile_matching_response_location_data import ProfileMatchingResponseLocationData
from phenom.api.recommendation.models.profile_matching_response_skill_gap import ProfileMatchingResponseSkillGap
from phenom.api.recommendation.models.similar_jobs_request import SimilarJobsRequest
from phenom.api.recommendation.models.similar_jobs_response import SimilarJobsResponse
from phenom.api.recommendation.models.similar_jobs_response_data import SimilarJobsResponseData
from phenom.api.recommendation.models.similar_jobs_response_data_similar_jobs import SimilarJobsResponseDataSimilarJobs
from phenom.api.recommendation.models.user_profile import UserProfile
