# coding: utf-8

"""
    aisourcing-api

    AI matching FitScore provides a concise assessment indicating how well a candidate aligns with a job based on their skills, experience, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SkillMatchingResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'matching_skills': 'list[str]',
        'matching_skills_count': 'int',
        'unmatching_skills': 'list[str]',
        'unmatching_skills_count': 'int',
        'total_job_skills': 'int'
    }

    attribute_map = {
        'matching_skills': 'matchingSkills',
        'matching_skills_count': 'matchingSkillsCount',
        'unmatching_skills': 'unmatchingSkills',
        'unmatching_skills_count': 'unmatchingSkillsCount',
        'total_job_skills': 'totalJobSkills'
    }

    def __init__(self, matching_skills=None, matching_skills_count=None, unmatching_skills=None, unmatching_skills_count=None, total_job_skills=None):  # noqa: E501
        """SkillMatchingResponse - a model defined in Swagger"""  # noqa: E501
        self._matching_skills = None
        self._matching_skills_count = None
        self._unmatching_skills = None
        self._unmatching_skills_count = None
        self._total_job_skills = None
        self.discriminator = None
        if matching_skills is not None:
            self.matching_skills = matching_skills
        if matching_skills_count is not None:
            self.matching_skills_count = matching_skills_count
        if unmatching_skills is not None:
            self.unmatching_skills = unmatching_skills
        if unmatching_skills_count is not None:
            self.unmatching_skills_count = unmatching_skills_count
        if total_job_skills is not None:
            self.total_job_skills = total_job_skills

    @property
    def matching_skills(self):
        """Gets the matching_skills of this SkillMatchingResponse.  # noqa: E501

        List of matched skills.  # noqa: E501

        :return: The matching_skills of this SkillMatchingResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._matching_skills

    @matching_skills.setter
    def matching_skills(self, matching_skills):
        """Sets the matching_skills of this SkillMatchingResponse.

        List of matched skills.  # noqa: E501

        :param matching_skills: The matching_skills of this SkillMatchingResponse.  # noqa: E501
        :type: list[str]
        """

        self._matching_skills = matching_skills

    @property
    def matching_skills_count(self):
        """Gets the matching_skills_count of this SkillMatchingResponse.  # noqa: E501

        Count of matched skills.  # noqa: E501

        :return: The matching_skills_count of this SkillMatchingResponse.  # noqa: E501
        :rtype: int
        """
        return self._matching_skills_count

    @matching_skills_count.setter
    def matching_skills_count(self, matching_skills_count):
        """Sets the matching_skills_count of this SkillMatchingResponse.

        Count of matched skills.  # noqa: E501

        :param matching_skills_count: The matching_skills_count of this SkillMatchingResponse.  # noqa: E501
        :type: int
        """

        self._matching_skills_count = matching_skills_count

    @property
    def unmatching_skills(self):
        """Gets the unmatching_skills of this SkillMatchingResponse.  # noqa: E501

        List of unmatched skills.  # noqa: E501

        :return: The unmatching_skills of this SkillMatchingResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._unmatching_skills

    @unmatching_skills.setter
    def unmatching_skills(self, unmatching_skills):
        """Sets the unmatching_skills of this SkillMatchingResponse.

        List of unmatched skills.  # noqa: E501

        :param unmatching_skills: The unmatching_skills of this SkillMatchingResponse.  # noqa: E501
        :type: list[str]
        """

        self._unmatching_skills = unmatching_skills

    @property
    def unmatching_skills_count(self):
        """Gets the unmatching_skills_count of this SkillMatchingResponse.  # noqa: E501

        Count of unmatched skills.  # noqa: E501

        :return: The unmatching_skills_count of this SkillMatchingResponse.  # noqa: E501
        :rtype: int
        """
        return self._unmatching_skills_count

    @unmatching_skills_count.setter
    def unmatching_skills_count(self, unmatching_skills_count):
        """Sets the unmatching_skills_count of this SkillMatchingResponse.

        Count of unmatched skills.  # noqa: E501

        :param unmatching_skills_count: The unmatching_skills_count of this SkillMatchingResponse.  # noqa: E501
        :type: int
        """

        self._unmatching_skills_count = unmatching_skills_count

    @property
    def total_job_skills(self):
        """Gets the total_job_skills of this SkillMatchingResponse.  # noqa: E501

        Count of total job skills.  # noqa: E501

        :return: The total_job_skills of this SkillMatchingResponse.  # noqa: E501
        :rtype: int
        """
        return self._total_job_skills

    @total_job_skills.setter
    def total_job_skills(self, total_job_skills):
        """Sets the total_job_skills of this SkillMatchingResponse.

        Count of total job skills.  # noqa: E501

        :param total_job_skills: The total_job_skills of this SkillMatchingResponse.  # noqa: E501
        :type: int
        """

        self._total_job_skills = total_job_skills

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SkillMatchingResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SkillMatchingResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
