# coding: utf-8

"""
    recommendations-api

    These APIs provide job suggestions based on your profile, akin job listings, and nearby job opportunities tailored to your qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobRecommendation(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'locale': 'str',
        'site_type': 'str',
        'user_type': 'str',
        'user_id': 'str',
        'user_profile': 'UserProfile',
        'max_recommendation_size': 'int'
    }

    attribute_map = {
        'locale': 'locale',
        'site_type': 'siteType',
        'user_type': 'userType',
        'user_id': 'userId',
        'user_profile': 'userProfile',
        'max_recommendation_size': 'maxRecommendationSize'
    }

    def __init__(self, locale=None, site_type='external', user_type='external', user_id=None, user_profile=None, max_recommendation_size=None):  # noqa: E501
        """JobRecommendation - a model defined in Swagger"""  # noqa: E501
        self._locale = None
        self._site_type = None
        self._user_type = None
        self._user_id = None
        self._user_profile = None
        self._max_recommendation_size = None
        self.discriminator = None
        if locale is not None:
            self.locale = locale
        if site_type is not None:
            self.site_type = site_type
        if user_type is not None:
            self.user_type = user_type
        if user_id is not None:
            self.user_id = user_id
        if user_profile is not None:
            self.user_profile = user_profile
        if max_recommendation_size is not None:
            self.max_recommendation_size = max_recommendation_size

    @property
    def locale(self):
        """Gets the locale of this JobRecommendation.  # noqa: E501

        Locale of the site (Language_Country) - Example: en_US.  # noqa: E501

        :return: The locale of this JobRecommendation.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this JobRecommendation.

        Locale of the site (Language_Country) - Example: en_US.  # noqa: E501

        :param locale: The locale of this JobRecommendation.  # noqa: E501
        :type: str
        """

        self._locale = locale

    @property
    def site_type(self):
        """Gets the site_type of this JobRecommendation.  # noqa: E501

        Persona Value - Example: Internal, External.  # noqa: E501

        :return: The site_type of this JobRecommendation.  # noqa: E501
        :rtype: str
        """
        return self._site_type

    @site_type.setter
    def site_type(self, site_type):
        """Sets the site_type of this JobRecommendation.

        Persona Value - Example: Internal, External.  # noqa: E501

        :param site_type: The site_type of this JobRecommendation.  # noqa: E501
        :type: str
        """

        self._site_type = site_type

    @property
    def user_type(self):
        """Gets the user_type of this JobRecommendation.  # noqa: E501

        Type of the user - Internal or External User.  # noqa: E501

        :return: The user_type of this JobRecommendation.  # noqa: E501
        :rtype: str
        """
        return self._user_type

    @user_type.setter
    def user_type(self, user_type):
        """Sets the user_type of this JobRecommendation.

        Type of the user - Internal or External User.  # noqa: E501

        :param user_type: The user_type of this JobRecommendation.  # noqa: E501
        :type: str
        """

        self._user_type = user_type

    @property
    def user_id(self):
        """Gets the user_id of this JobRecommendation.  # noqa: E501

        Unique identified for a user.  # noqa: E501

        :return: The user_id of this JobRecommendation.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this JobRecommendation.

        Unique identified for a user.  # noqa: E501

        :param user_id: The user_id of this JobRecommendation.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_profile(self):
        """Gets the user_profile of this JobRecommendation.  # noqa: E501


        :return: The user_profile of this JobRecommendation.  # noqa: E501
        :rtype: UserProfile
        """
        return self._user_profile

    @user_profile.setter
    def user_profile(self, user_profile):
        """Sets the user_profile of this JobRecommendation.


        :param user_profile: The user_profile of this JobRecommendation.  # noqa: E501
        :type: UserProfile
        """

        self._user_profile = user_profile

    @property
    def max_recommendation_size(self):
        """Gets the max_recommendation_size of this JobRecommendation.  # noqa: E501

        Maximum recommendations to be provided in response.  # noqa: E501

        :return: The max_recommendation_size of this JobRecommendation.  # noqa: E501
        :rtype: int
        """
        return self._max_recommendation_size

    @max_recommendation_size.setter
    def max_recommendation_size(self, max_recommendation_size):
        """Sets the max_recommendation_size of this JobRecommendation.

        Maximum recommendations to be provided in response.  # noqa: E501

        :param max_recommendation_size: The max_recommendation_size of this JobRecommendation.  # noqa: E501
        :type: int
        """

        self._max_recommendation_size = max_recommendation_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobRecommendation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobRecommendation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
