# coding: utf-8

"""
    ex-search-api

    These APIs helps in searching and providing suggestions based on keywords within employee profiles.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmployeeSearchRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'keyword': 'str',
        'common': 'CommonNode',
        '_from': 'int',
        'size': 'int',
        'filters': 'FiltersNode',
        'tab_info': 'TabInfoNode'
    }

    attribute_map = {
        'keyword': 'keyword',
        'common': 'common',
        '_from': 'from',
        'size': 'size',
        'filters': 'filters',
        'tab_info': 'tabInfo'
    }

    def __init__(self, keyword=None, common=None, _from=None, size=None, filters=None, tab_info=None):  # noqa: E501
        """EmployeeSearchRequest - a model defined in Swagger"""  # noqa: E501
        self._keyword = None
        self._common = None
        self.__from = None
        self._size = None
        self._filters = None
        self._tab_info = None
        self.discriminator = None
        if keyword is not None:
            self.keyword = keyword
        if common is not None:
            self.common = common
        if _from is not None:
            self._from = _from
        if size is not None:
            self.size = size
        if filters is not None:
            self.filters = filters
        if tab_info is not None:
            self.tab_info = tab_info

    @property
    def keyword(self):
        """Gets the keyword of this EmployeeSearchRequest.  # noqa: E501

        Keyword to search.  # noqa: E501

        :return: The keyword of this EmployeeSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._keyword

    @keyword.setter
    def keyword(self, keyword):
        """Sets the keyword of this EmployeeSearchRequest.

        Keyword to search.  # noqa: E501

        :param keyword: The keyword of this EmployeeSearchRequest.  # noqa: E501
        :type: str
        """

        self._keyword = keyword

    @property
    def common(self):
        """Gets the common of this EmployeeSearchRequest.  # noqa: E501


        :return: The common of this EmployeeSearchRequest.  # noqa: E501
        :rtype: CommonNode
        """
        return self._common

    @common.setter
    def common(self, common):
        """Sets the common of this EmployeeSearchRequest.


        :param common: The common of this EmployeeSearchRequest.  # noqa: E501
        :type: CommonNode
        """

        self._common = common

    @property
    def _from(self):
        """Gets the _from of this EmployeeSearchRequest.  # noqa: E501

        Starting point from which the data should be retrieved.  # noqa: E501

        :return: The _from of this EmployeeSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this EmployeeSearchRequest.

        Starting point from which the data should be retrieved.  # noqa: E501

        :param _from: The _from of this EmployeeSearchRequest.  # noqa: E501
        :type: int
        """

        self.__from = _from

    @property
    def size(self):
        """Gets the size of this EmployeeSearchRequest.  # noqa: E501

        Size of the response.  # noqa: E501

        :return: The size of this EmployeeSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this EmployeeSearchRequest.

        Size of the response.  # noqa: E501

        :param size: The size of this EmployeeSearchRequest.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def filters(self):
        """Gets the filters of this EmployeeSearchRequest.  # noqa: E501


        :return: The filters of this EmployeeSearchRequest.  # noqa: E501
        :rtype: FiltersNode
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this EmployeeSearchRequest.


        :param filters: The filters of this EmployeeSearchRequest.  # noqa: E501
        :type: FiltersNode
        """

        self._filters = filters

    @property
    def tab_info(self):
        """Gets the tab_info of this EmployeeSearchRequest.  # noqa: E501


        :return: The tab_info of this EmployeeSearchRequest.  # noqa: E501
        :rtype: TabInfoNode
        """
        return self._tab_info

    @tab_info.setter
    def tab_info(self, tab_info):
        """Sets the tab_info of this EmployeeSearchRequest.


        :param tab_info: The tab_info of this EmployeeSearchRequest.  # noqa: E501
        :type: TabInfoNode
        """

        self._tab_info = tab_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmployeeSearchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmployeeSearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
