# coding: utf-8

# flake8: noqa

"""
    communications-email

    These APIs ensures an easy integration process of email management for developers to send, read, and track email histories within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.communicationsemail.email_communications_api import EmailCommunicationsApi
from phenom.api.communicationsemail.forward_profile_api import ForwardProfileApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.communicationsemail.models.api_error import ApiError
from phenom.api.communicationsemail.models.api_link import ApiLink
from phenom.api.communicationsemail.models.bad_request import BadRequest
from phenom.api.communicationsemail.models.email_activity import EmailActivity
from phenom.api.communicationsemail.models.email_activity_data import EmailActivityData
from phenom.api.communicationsemail.models.email_history import EmailHistory
from phenom.api.communicationsemail.models.email_history_data import EmailHistoryData
from phenom.api.communicationsemail.models.email_history_pagination import EmailHistoryPagination
from phenom.api.communicationsemail.models.forward_profile_activity import ForwardProfileActivity
from phenom.api.communicationsemail.models.forward_profile_activity_data import ForwardProfileActivityData
from phenom.api.communicationsemail.models.forward_profile_activity_pagination import ForwardProfileActivityPagination
from phenom.api.communicationsemail.models.forward_profile_request import ForwardProfileRequest
from phenom.api.communicationsemail.models.forward_profile_response import ForwardProfileResponse
from phenom.api.communicationsemail.models.forward_profile_response_data import ForwardProfileResponseData
from phenom.api.communicationsemail.models.internal_server_error import InternalServerError
from phenom.api.communicationsemail.models.send_email_request import SendEmailRequest
from phenom.api.communicationsemail.models.send_email_response import SendEmailResponse
from phenom.api.communicationsemail.models.send_email_response_data import SendEmailResponseData
from phenom.api.communicationsemail.models.unauthorized_request import UnauthorizedRequest
