# coding: utf-8

"""
    prediction-api

    An API that predicts skills based on job titles and provided skill sets.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SkillPredictionRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'titles': 'list[str]',
        'skills': 'list[str]',
        'size': 'int',
        'source': 'str'
    }

    attribute_map = {
        'titles': 'titles',
        'skills': 'skills',
        'size': 'size',
        'source': 'source'
    }

    def __init__(self, titles=None, skills=None, size=10, source=None):  # noqa: E501
        """SkillPredictionRequest - a model defined in Swagger"""  # noqa: E501
        self._titles = None
        self._skills = None
        self._size = None
        self._source = None
        self.discriminator = None
        if titles is not None:
            self.titles = titles
        if skills is not None:
            self.skills = skills
        if size is not None:
            self.size = size
        if source is not None:
            self.source = source

    @property
    def titles(self):
        """Gets the titles of this SkillPredictionRequest.  # noqa: E501

        Titles' List.  # noqa: E501

        :return: The titles of this SkillPredictionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._titles

    @titles.setter
    def titles(self, titles):
        """Sets the titles of this SkillPredictionRequest.

        Titles' List.  # noqa: E501

        :param titles: The titles of this SkillPredictionRequest.  # noqa: E501
        :type: list[str]
        """

        self._titles = titles

    @property
    def skills(self):
        """Gets the skills of this SkillPredictionRequest.  # noqa: E501

        Skills' List.  # noqa: E501

        :return: The skills of this SkillPredictionRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._skills

    @skills.setter
    def skills(self, skills):
        """Sets the skills of this SkillPredictionRequest.

        Skills' List.  # noqa: E501

        :param skills: The skills of this SkillPredictionRequest.  # noqa: E501
        :type: list[str]
        """

        self._skills = skills

    @property
    def size(self):
        """Gets the size of this SkillPredictionRequest.  # noqa: E501

        Size of skills to return.  # noqa: E501

        :return: The size of this SkillPredictionRequest.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this SkillPredictionRequest.

        Size of skills to return.  # noqa: E501

        :param size: The size of this SkillPredictionRequest.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def source(self):
        """Gets the source of this SkillPredictionRequest.  # noqa: E501

        Source.  # noqa: E501

        :return: The source of this SkillPredictionRequest.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this SkillPredictionRequest.

        Source.  # noqa: E501

        :param source: The source of this SkillPredictionRequest.  # noqa: E501
        :type: str
        """

        self._source = source

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SkillPredictionRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SkillPredictionRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
