# coding: utf-8

# flake8: noqa

"""
    aisourcing-api

    AI matching FitScore provides a concise assessment indicating how well a candidate aligns with a job based on their skills, experience, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.aisourcing.ai_matching_api import AIMatchingApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.aisourcing.models.error_response import ErrorResponse
from phenom.api.aisourcing.models.fit_score_request import FitScoreRequest
from phenom.api.aisourcing.models.fitscore_bad_request import FitscoreBadRequest
from phenom.api.aisourcing.models.fitscore_response import FitscoreResponse
from phenom.api.aisourcing.models.fitscore_response_result import FitscoreResponseResult
from phenom.api.aisourcing.models.fitscore_response_skill_gap import FitscoreResponseSkillGap
from phenom.api.aisourcing.models.preferred_locations import PreferredLocations
from phenom.api.aisourcing.models.preferred_locations_latlong import PreferredLocationsLatlong
from phenom.api.aisourcing.models.skill_matching_bad_request import SkillMatchingBadRequest
from phenom.api.aisourcing.models.skill_matching_error_response import SkillMatchingErrorResponse
from phenom.api.aisourcing.models.skill_matching_response import SkillMatchingResponse
from phenom.api.aisourcing.models.user_profile_fit_score import UserProfileFitScore
