# coding: utf-8

# flake8: noqa

"""
    tags-api

    These APIs enable tag management for candidates, offering functionalities to create, update, delete tags, and add or remove them from candidate profiles.  # noqa: E501

    OpenAPI spec version: 1.0.3
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.tags.candidates_api import CandidatesApi
from phenom.api.tags.tags_api import TagsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.tags.models.bad_request import BadRequest
from phenom.api.tags.models.bad_request_errors import BadRequestErrors
from phenom.api.tags.models.candidate_tags_association import CandidateTagsAssociation
from phenom.api.tags.models.create_tag_duplicate import CreateTagDuplicate
from phenom.api.tags.models.create_tag_request import CreateTagRequest
from phenom.api.tags.models.create_tag_response import CreateTagResponse
from phenom.api.tags.models.delete_tag_not_found import DeleteTagNotFound
from phenom.api.tags.models.get_tag_associations_response import GetTagAssociationsResponse
from phenom.api.tags.models.get_tag_associations_response_pagination import GetTagAssociationsResponsePagination
from phenom.api.tags.models.get_tags_response import GetTagsResponse
from phenom.api.tags.models.get_tags_response_data import GetTagsResponseData
from phenom.api.tags.models.get_tags_response_pagination import GetTagsResponsePagination
from phenom.api.tags.models.no_content_response import NoContentResponse
from phenom.api.tags.models.tag_failure import TagFailure
from phenom.api.tags.models.tag_response import TagResponse
from phenom.api.tags.models.update_tag_request import UpdateTagRequest
