# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'category': 'str',
        'location': 'str',
        'title': 'str',
        'job_id': 'str'
    }

    attribute_map = {
        'category': 'category',
        'location': 'location',
        'title': 'title',
        'job_id': 'jobId'
    }

    def __init__(self, category=None, location=None, title=None, job_id=None):  # noqa: E501
        """GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails - a model defined in Swagger"""  # noqa: E501
        self._category = None
        self._location = None
        self._title = None
        self._job_id = None
        self.discriminator = None
        self.category = category
        self.location = location
        self.title = title
        self.job_id = job_id

    @property
    def category(self):
        """Gets the category of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501

        Job category.  # noqa: E501

        :return: The category of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.

        Job category.  # noqa: E501

        :param category: The category of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :type: str
        """
        if category is None:
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def location(self):
        """Gets the location of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501

        Job posted location.  # noqa: E501

        :return: The location of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.

        Job posted location.  # noqa: E501

        :param location: The location of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :type: str
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def title(self):
        """Gets the title of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501

        Job title.  # noqa: E501

        :return: The title of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.

        Job title.  # noqa: E501

        :param title: The title of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError("Invalid value for `title`, must not be `None`")  # noqa: E501

        self._title = title

    @property
    def job_id(self):
        """Gets the job_id of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501

        Job id of the job.  # noqa: E501

        :return: The job_id of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.

        Job id of the job.  # noqa: E501

        :param job_id: The job_id of this GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails.  # noqa: E501
        :type: str
        """
        if job_id is None:
            raise ValueError("Invalid value for `job_id`, must not be `None`")  # noqa: E501

        self._job_id = job_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAllInterviewsForCandidateResponseDataInterviewDetailsJobDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
