# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetProjectAssociationsResponsePagination(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'size': 'float',
        '_from': 'float',
        'total_count': 'float'
    }

    attribute_map = {
        'size': 'size',
        '_from': 'from',
        'total_count': 'totalCount'
    }

    def __init__(self, size=None, _from=None, total_count=None):  # noqa: E501
        """GetProjectAssociationsResponsePagination - a model defined in Swagger"""  # noqa: E501
        self._size = None
        self.__from = None
        self._total_count = None
        self.discriminator = None
        self.size = size
        self._from = _from
        self.total_count = total_count

    @property
    def size(self):
        """Gets the size of this GetProjectAssociationsResponsePagination.  # noqa: E501

        Number of candidateIds per page in the paginated response.  # noqa: E501

        :return: The size of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this GetProjectAssociationsResponsePagination.

        Number of candidateIds per page in the paginated response.  # noqa: E501

        :param size: The size of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :type: float
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    @property
    def _from(self):
        """Gets the _from of this GetProjectAssociationsResponsePagination.  # noqa: E501

        Index of the first candidateId in the current response.  # noqa: E501

        :return: The _from of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :rtype: float
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this GetProjectAssociationsResponsePagination.

        Index of the first candidateId in the current response.  # noqa: E501

        :param _from: The _from of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :type: float
        """
        if _from is None:
            raise ValueError("Invalid value for `_from`, must not be `None`")  # noqa: E501

        self.__from = _from

    @property
    def total_count(self):
        """Gets the total_count of this GetProjectAssociationsResponsePagination.  # noqa: E501

        Total count of candidateIds.  # noqa: E501

        :return: The total_count of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :rtype: float
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this GetProjectAssociationsResponsePagination.

        Total count of candidateIds.  # noqa: E501

        :param total_count: The total_count of this GetProjectAssociationsResponsePagination.  # noqa: E501
        :type: float
        """
        if total_count is None:
            raise ValueError("Invalid value for `total_count`, must not be `None`")  # noqa: E501

        self._total_count = total_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetProjectAssociationsResponsePagination, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetProjectAssociationsResponsePagination):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
