# coding: utf-8

"""
    employees-api-careerpath

    The Employee upskill APIs are related to the career pathing that an employee can use them for upskilling in an organisation.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class UpdateCareerPath(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'path': 'list[PathItem]',
        'current_job_profile': 'CurrentJobProfile',
        'path_id': 'str'
    }

    attribute_map = {
        'path': 'path',
        'current_job_profile': 'currentJobProfile',
        'path_id': 'pathId'
    }

    def __init__(self, path=None, current_job_profile=None, path_id='8168055'):  # noqa: E501
        """UpdateCareerPath - a model defined in Swagger"""  # noqa: E501
        self._path = None
        self._current_job_profile = None
        self._path_id = None
        self.discriminator = None
        if path is not None:
            self.path = path
        if current_job_profile is not None:
            self.current_job_profile = current_job_profile
        if path_id is not None:
            self.path_id = path_id

    @property
    def path(self):
        """Gets the path of this UpdateCareerPath.  # noqa: E501


        :return: The path of this UpdateCareerPath.  # noqa: E501
        :rtype: list[PathItem]
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this UpdateCareerPath.


        :param path: The path of this UpdateCareerPath.  # noqa: E501
        :type: list[PathItem]
        """

        self._path = path

    @property
    def current_job_profile(self):
        """Gets the current_job_profile of this UpdateCareerPath.  # noqa: E501


        :return: The current_job_profile of this UpdateCareerPath.  # noqa: E501
        :rtype: CurrentJobProfile
        """
        return self._current_job_profile

    @current_job_profile.setter
    def current_job_profile(self, current_job_profile):
        """Sets the current_job_profile of this UpdateCareerPath.


        :param current_job_profile: The current_job_profile of this UpdateCareerPath.  # noqa: E501
        :type: CurrentJobProfile
        """

        self._current_job_profile = current_job_profile

    @property
    def path_id(self):
        """Gets the path_id of this UpdateCareerPath.  # noqa: E501

        Path Id - unique field to identify the careerPath of the employee.  # noqa: E501

        :return: The path_id of this UpdateCareerPath.  # noqa: E501
        :rtype: str
        """
        return self._path_id

    @path_id.setter
    def path_id(self, path_id):
        """Sets the path_id of this UpdateCareerPath.

        Path Id - unique field to identify the careerPath of the employee.  # noqa: E501

        :param path_id: The path_id of this UpdateCareerPath.  # noqa: E501
        :type: str
        """

        self._path_id = path_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UpdateCareerPath, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateCareerPath):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
