# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidatesRequestFilters(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'filter_name': 'str',
        'possible_values': 'list[str]',
        'associativity': 'str'
    }

    attribute_map = {
        'filter_name': 'filterName',
        'possible_values': 'possibleValues',
        'associativity': 'associativity'
    }

    def __init__(self, filter_name=None, possible_values=None, associativity=None):  # noqa: E501
        """GetCandidatesRequestFilters - a model defined in Swagger"""  # noqa: E501
        self._filter_name = None
        self._possible_values = None
        self._associativity = None
        self.discriminator = None
        if filter_name is not None:
            self.filter_name = filter_name
        if possible_values is not None:
            self.possible_values = possible_values
        if associativity is not None:
            self.associativity = associativity

    @property
    def filter_name(self):
        """Gets the filter_name of this GetCandidatesRequestFilters.  # noqa: E501

        Dpecific filter types that can be applied.  # noqa: E501

        :return: The filter_name of this GetCandidatesRequestFilters.  # noqa: E501
        :rtype: str
        """
        return self._filter_name

    @filter_name.setter
    def filter_name(self, filter_name):
        """Sets the filter_name of this GetCandidatesRequestFilters.

        Dpecific filter types that can be applied.  # noqa: E501

        :param filter_name: The filter_name of this GetCandidatesRequestFilters.  # noqa: E501
        :type: str
        """

        self._filter_name = filter_name

    @property
    def possible_values(self):
        """Gets the possible_values of this GetCandidatesRequestFilters.  # noqa: E501

        Possible values within a list of values corresponding to the filter selected.  # noqa: E501

        :return: The possible_values of this GetCandidatesRequestFilters.  # noqa: E501
        :rtype: list[str]
        """
        return self._possible_values

    @possible_values.setter
    def possible_values(self, possible_values):
        """Sets the possible_values of this GetCandidatesRequestFilters.

        Possible values within a list of values corresponding to the filter selected.  # noqa: E501

        :param possible_values: The possible_values of this GetCandidatesRequestFilters.  # noqa: E501
        :type: list[str]
        """

        self._possible_values = possible_values

    @property
    def associativity(self):
        """Gets the associativity of this GetCandidatesRequestFilters.  # noqa: E501

        Condition to apply either and || or.  # noqa: E501

        :return: The associativity of this GetCandidatesRequestFilters.  # noqa: E501
        :rtype: str
        """
        return self._associativity

    @associativity.setter
    def associativity(self, associativity):
        """Sets the associativity of this GetCandidatesRequestFilters.

        Condition to apply either and || or.  # noqa: E501

        :param associativity: The associativity of this GetCandidatesRequestFilters.  # noqa: E501
        :type: str
        """

        self._associativity = associativity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidatesRequestFilters, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidatesRequestFilters):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
