# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidatesResponseDataEmailList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'email': 'str',
        'field_id': 'str',
        'status': 'str'
    }

    attribute_map = {
        'type': 'type',
        'email': 'email',
        'field_id': 'fieldID',
        'status': 'status'
    }

    def __init__(self, type=None, email=None, field_id=None, status=None):  # noqa: E501
        """GetCandidatesResponseDataEmailList - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._email = None
        self._field_id = None
        self._status = None
        self.discriminator = None
        if type is not None:
            self.type = type
        if email is not None:
            self.email = email
        if field_id is not None:
            self.field_id = field_id
        if status is not None:
            self.status = status

    @property
    def type(self):
        """Gets the type of this GetCandidatesResponseDataEmailList.  # noqa: E501

        Indicates whether the email is primary or secondary.  # noqa: E501

        :return: The type of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GetCandidatesResponseDataEmailList.

        Indicates whether the email is primary or secondary.  # noqa: E501

        :param type: The type of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def email(self):
        """Gets the email of this GetCandidatesResponseDataEmailList.  # noqa: E501

        Email address of the candidate.  # noqa: E501

        :return: The email of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this GetCandidatesResponseDataEmailList.

        Email address of the candidate.  # noqa: E501

        :param email: The email of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def field_id(self):
        """Gets the field_id of this GetCandidatesResponseDataEmailList.  # noqa: E501

        Field identifier for the email.  # noqa: E501

        :return: The field_id of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this GetCandidatesResponseDataEmailList.

        Field identifier for the email.  # noqa: E501

        :param field_id: The field_id of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    @property
    def status(self):
        """Gets the status of this GetCandidatesResponseDataEmailList.  # noqa: E501

        Status of the email.  # noqa: E501

        :return: The status of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetCandidatesResponseDataEmailList.

        Status of the email.  # noqa: E501

        :param status: The status of this GetCandidatesResponseDataEmailList.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidatesResponseDataEmailList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidatesResponseDataEmailList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
