# coding: utf-8

"""
    recommendations-api

    These APIs provide job suggestions based on your profile, akin job listings, and nearby job opportunities tailored to your qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobNode(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'title': 'str',
        'job_id': 'str',
        'city': 'str',
        'state': 'str',
        'country': 'str'
    }

    attribute_map = {
        'title': 'title',
        'job_id': 'jobId',
        'city': 'city',
        'state': 'state',
        'country': 'country'
    }

    def __init__(self, title=None, job_id=None, city=None, state=None, country=None):  # noqa: E501
        """JobNode - a model defined in Swagger"""  # noqa: E501
        self._title = None
        self._job_id = None
        self._city = None
        self._state = None
        self._country = None
        self.discriminator = None
        if title is not None:
            self.title = title
        if job_id is not None:
            self.job_id = job_id
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country

    @property
    def title(self):
        """Gets the title of this JobNode.  # noqa: E501

        Title of the recommended job.  # noqa: E501

        :return: The title of this JobNode.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this JobNode.

        Title of the recommended job.  # noqa: E501

        :param title: The title of this JobNode.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def job_id(self):
        """Gets the job_id of this JobNode.  # noqa: E501

        Unique identifier for a job.  # noqa: E501

        :return: The job_id of this JobNode.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this JobNode.

        Unique identifier for a job.  # noqa: E501

        :param job_id: The job_id of this JobNode.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def city(self):
        """Gets the city of this JobNode.  # noqa: E501

        Primary city of the job's location.  # noqa: E501

        :return: The city of this JobNode.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this JobNode.

        Primary city of the job's location.  # noqa: E501

        :param city: The city of this JobNode.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this JobNode.  # noqa: E501

        Primary state of the job's location.  # noqa: E501

        :return: The state of this JobNode.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this JobNode.

        Primary state of the job's location.  # noqa: E501

        :param state: The state of this JobNode.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this JobNode.  # noqa: E501

        Primary country of the job's location.  # noqa: E501

        :return: The country of this JobNode.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this JobNode.

        Primary country of the job's location.  # noqa: E501

        :param country: The country of this JobNode.  # noqa: E501
        :type: str
        """

        self._country = country

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobNode, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobNode):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
