# coding: utf-8

"""
    servicehub-public-api

    Public APIs for managing user data.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SearchRequestDateFilter(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'start_date': 'str',
        'end_date': 'str'
    }

    attribute_map = {
        'name': 'name',
        'start_date': 'startDate',
        'end_date': 'endDate'
    }

    def __init__(self, name=None, start_date=None, end_date=None):  # noqa: E501
        """SearchRequestDateFilter - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._start_date = None
        self._end_date = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date

    @property
    def name(self):
        """Gets the name of this SearchRequestDateFilter.  # noqa: E501

        Name of the date filter.  # noqa: E501

        :return: The name of this SearchRequestDateFilter.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SearchRequestDateFilter.

        Name of the date filter.  # noqa: E501

        :param name: The name of this SearchRequestDateFilter.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def start_date(self):
        """Gets the start_date of this SearchRequestDateFilter.  # noqa: E501

        Start date for the date filter.  # noqa: E501

        :return: The start_date of this SearchRequestDateFilter.  # noqa: E501
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this SearchRequestDateFilter.

        Start date for the date filter.  # noqa: E501

        :param start_date: The start_date of this SearchRequestDateFilter.  # noqa: E501
        :type: str
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this SearchRequestDateFilter.  # noqa: E501

        End date for the date filter.  # noqa: E501

        :return: The end_date of this SearchRequestDateFilter.  # noqa: E501
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this SearchRequestDateFilter.

        End date for the date filter.  # noqa: E501

        :param end_date: The end_date of this SearchRequestDateFilter.  # noqa: E501
        :type: str
        """

        self._end_date = end_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SearchRequestDateFilter, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchRequestDateFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
