# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetInterviewDetailsResponseDataCandidateInfo(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'candidate_id': 'str',
        'preferred_first_name': 'str'
    }

    attribute_map = {
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email': 'email',
        'candidate_id': 'candidateId',
        'preferred_first_name': 'preferredFirstName'
    }

    def __init__(self, first_name=None, last_name=None, email=None, candidate_id=None, preferred_first_name=None):  # noqa: E501
        """GetInterviewDetailsResponseDataCandidateInfo - a model defined in Swagger"""  # noqa: E501
        self._first_name = None
        self._last_name = None
        self._email = None
        self._candidate_id = None
        self._preferred_first_name = None
        self.discriminator = None
        self.first_name = first_name
        self.last_name = last_name
        self.email = email
        self.candidate_id = candidate_id
        self.preferred_first_name = preferred_first_name

    @property
    def first_name(self):
        """Gets the first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501

        Candidate first name.  # noqa: E501

        :return: The first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this GetInterviewDetailsResponseDataCandidateInfo.

        Candidate first name.  # noqa: E501

        :param first_name: The first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :type: str
        """
        if first_name is None:
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501

        Candidate last name.  # noqa: E501

        :return: The last_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this GetInterviewDetailsResponseDataCandidateInfo.

        Candidate last name.  # noqa: E501

        :param last_name: The last_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :type: str
        """
        if last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501

        Candidate email.  # noqa: E501

        :return: The email of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this GetInterviewDetailsResponseDataCandidateInfo.

        Candidate email.  # noqa: E501

        :param email: The email of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def candidate_id(self):
        """Gets the candidate_id of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501

        Candidate id.  # noqa: E501

        :return: The candidate_id of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :rtype: str
        """
        return self._candidate_id

    @candidate_id.setter
    def candidate_id(self, candidate_id):
        """Sets the candidate_id of this GetInterviewDetailsResponseDataCandidateInfo.

        Candidate id.  # noqa: E501

        :param candidate_id: The candidate_id of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :type: str
        """
        if candidate_id is None:
            raise ValueError("Invalid value for `candidate_id`, must not be `None`")  # noqa: E501

        self._candidate_id = candidate_id

    @property
    def preferred_first_name(self):
        """Gets the preferred_first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501

        Candidate preferred first name.  # noqa: E501

        :return: The preferred_first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :rtype: str
        """
        return self._preferred_first_name

    @preferred_first_name.setter
    def preferred_first_name(self, preferred_first_name):
        """Sets the preferred_first_name of this GetInterviewDetailsResponseDataCandidateInfo.

        Candidate preferred first name.  # noqa: E501

        :param preferred_first_name: The preferred_first_name of this GetInterviewDetailsResponseDataCandidateInfo.  # noqa: E501
        :type: str
        """
        if preferred_first_name is None:
            raise ValueError("Invalid value for `preferred_first_name`, must not be `None`")  # noqa: E501

        self._preferred_first_name = preferred_first_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetInterviewDetailsResponseDataCandidateInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetInterviewDetailsResponseDataCandidateInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
