# coding: utf-8

"""
    search-api

    These APIs helps to search and suggest based on keyword among available jobs.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class LocationData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'latlong': 'str',
        'location': 'str',
        'radius': 'int',
        'radius_unit': 'str'
    }

    attribute_map = {
        'latlong': 'latlong',
        'location': 'location',
        'radius': 'radius',
        'radius_unit': 'radiusUnit'
    }

    def __init__(self, latlong=None, location=None, radius=None, radius_unit=None):  # noqa: E501
        """LocationData - a model defined in Swagger"""  # noqa: E501
        self._latlong = None
        self._location = None
        self._radius = None
        self._radius_unit = None
        self.discriminator = None
        if latlong is not None:
            self.latlong = latlong
        if location is not None:
            self.location = location
        if radius is not None:
            self.radius = radius
        if radius_unit is not None:
            self.radius_unit = radius_unit

    @property
    def latlong(self):
        """Gets the latlong of this LocationData.  # noqa: E501

        Latitude, Longitude of the location.  # noqa: E501

        :return: The latlong of this LocationData.  # noqa: E501
        :rtype: str
        """
        return self._latlong

    @latlong.setter
    def latlong(self, latlong):
        """Sets the latlong of this LocationData.

        Latitude, Longitude of the location.  # noqa: E501

        :param latlong: The latlong of this LocationData.  # noqa: E501
        :type: str
        """

        self._latlong = latlong

    @property
    def location(self):
        """Gets the location of this LocationData.  # noqa: E501

        Location Value.  # noqa: E501

        :return: The location of this LocationData.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this LocationData.

        Location Value.  # noqa: E501

        :param location: The location of this LocationData.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def radius(self):
        """Gets the radius of this LocationData.  # noqa: E501

        Radius to consider from the entered location.  # noqa: E501

        :return: The radius of this LocationData.  # noqa: E501
        :rtype: int
        """
        return self._radius

    @radius.setter
    def radius(self, radius):
        """Sets the radius of this LocationData.

        Radius to consider from the entered location.  # noqa: E501

        :param radius: The radius of this LocationData.  # noqa: E501
        :type: int
        """

        self._radius = radius

    @property
    def radius_unit(self):
        """Gets the radius_unit of this LocationData.  # noqa: E501

        Radius unit to consider.  # noqa: E501

        :return: The radius_unit of this LocationData.  # noqa: E501
        :rtype: str
        """
        return self._radius_unit

    @radius_unit.setter
    def radius_unit(self, radius_unit):
        """Sets the radius_unit of this LocationData.

        Radius unit to consider.  # noqa: E501

        :param radius_unit: The radius_unit of this LocationData.  # noqa: E501
        :type: str
        """

        self._radius_unit = radius_unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LocationData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LocationData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
