# coding: utf-8

"""
    campaigns-email

    These APIs ensures an easy integration process of Email management for developers to send, read, and track Email campaigns within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmailCampaignHistoryData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'email_activity_id': 'str',
        'campaign_name': 'str',
        'campaign_type': 'str',
        'created_date': 'int'
    }

    attribute_map = {
        'email': 'email',
        'email_activity_id': 'emailActivityId',
        'campaign_name': 'campaignName',
        'campaign_type': 'campaignType',
        'created_date': 'createdDate'
    }

    def __init__(self, email=None, email_activity_id=None, campaign_name=None, campaign_type=None, created_date=None):  # noqa: E501
        """EmailCampaignHistoryData - a model defined in Swagger"""  # noqa: E501
        self._email = None
        self._email_activity_id = None
        self._campaign_name = None
        self._campaign_type = None
        self._created_date = None
        self.discriminator = None
        self.email = email
        self.email_activity_id = email_activity_id
        self.campaign_name = campaign_name
        self.campaign_type = campaign_type
        self.created_date = created_date

    @property
    def email(self):
        """Gets the email of this EmailCampaignHistoryData.  # noqa: E501

        Email associated with Email campaign History.  # noqa: E501

        :return: The email of this EmailCampaignHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this EmailCampaignHistoryData.

        Email associated with Email campaign History.  # noqa: E501

        :param email: The email of this EmailCampaignHistoryData.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def email_activity_id(self):
        """Gets the email_activity_id of this EmailCampaignHistoryData.  # noqa: E501

        Email Activity Id associated with Email Campaign History.  # noqa: E501

        :return: The email_activity_id of this EmailCampaignHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._email_activity_id

    @email_activity_id.setter
    def email_activity_id(self, email_activity_id):
        """Sets the email_activity_id of this EmailCampaignHistoryData.

        Email Activity Id associated with Email Campaign History.  # noqa: E501

        :param email_activity_id: The email_activity_id of this EmailCampaignHistoryData.  # noqa: E501
        :type: str
        """
        if email_activity_id is None:
            raise ValueError("Invalid value for `email_activity_id`, must not be `None`")  # noqa: E501

        self._email_activity_id = email_activity_id

    @property
    def campaign_name(self):
        """Gets the campaign_name of this EmailCampaignHistoryData.  # noqa: E501

        The Email CampaignName in the Email Campaign History.  # noqa: E501

        :return: The campaign_name of this EmailCampaignHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._campaign_name

    @campaign_name.setter
    def campaign_name(self, campaign_name):
        """Sets the campaign_name of this EmailCampaignHistoryData.

        The Email CampaignName in the Email Campaign History.  # noqa: E501

        :param campaign_name: The campaign_name of this EmailCampaignHistoryData.  # noqa: E501
        :type: str
        """
        if campaign_name is None:
            raise ValueError("Invalid value for `campaign_name`, must not be `None`")  # noqa: E501

        self._campaign_name = campaign_name

    @property
    def campaign_type(self):
        """Gets the campaign_type of this EmailCampaignHistoryData.  # noqa: E501

        Type of the email campaign in the Email Campaign History .  # noqa: E501

        :return: The campaign_type of this EmailCampaignHistoryData.  # noqa: E501
        :rtype: str
        """
        return self._campaign_type

    @campaign_type.setter
    def campaign_type(self, campaign_type):
        """Sets the campaign_type of this EmailCampaignHistoryData.

        Type of the email campaign in the Email Campaign History .  # noqa: E501

        :param campaign_type: The campaign_type of this EmailCampaignHistoryData.  # noqa: E501
        :type: str
        """
        if campaign_type is None:
            raise ValueError("Invalid value for `campaign_type`, must not be `None`")  # noqa: E501

        self._campaign_type = campaign_type

    @property
    def created_date(self):
        """Gets the created_date of this EmailCampaignHistoryData.  # noqa: E501

        Timestamp indicating when the email campaign history entry was created.  # noqa: E501

        :return: The created_date of this EmailCampaignHistoryData.  # noqa: E501
        :rtype: int
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this EmailCampaignHistoryData.

        Timestamp indicating when the email campaign history entry was created.  # noqa: E501

        :param created_date: The created_date of this EmailCampaignHistoryData.  # noqa: E501
        :type: int
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmailCampaignHistoryData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailCampaignHistoryData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
