# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobDetailsHiringTeamList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'role': 'str',
        'name': 'str',
        'email_id': 'str',
        'id': 'str',
        'source': 'str',
        'type': 'str'
    }

    attribute_map = {
        'role': 'role',
        'name': 'name',
        'email_id': 'emailId',
        'id': 'id',
        'source': 'source',
        'type': 'type'
    }

    def __init__(self, role=None, name=None, email_id=None, id=None, source=None, type=None):  # noqa: E501
        """JobDetailsHiringTeamList - a model defined in Swagger"""  # noqa: E501
        self._role = None
        self._name = None
        self._email_id = None
        self._id = None
        self._source = None
        self._type = None
        self.discriminator = None
        if role is not None:
            self.role = role
        if name is not None:
            self.name = name
        if email_id is not None:
            self.email_id = email_id
        if id is not None:
            self.id = id
        if source is not None:
            self.source = source
        if type is not None:
            self.type = type

    @property
    def role(self):
        """Gets the role of this JobDetailsHiringTeamList.  # noqa: E501

        Role of the team member related to the job.  # noqa: E501

        :return: The role of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this JobDetailsHiringTeamList.

        Role of the team member related to the job.  # noqa: E501

        :param role: The role of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def name(self):
        """Gets the name of this JobDetailsHiringTeamList.  # noqa: E501

        Name of the team member.  # noqa: E501

        :return: The name of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this JobDetailsHiringTeamList.

        Name of the team member.  # noqa: E501

        :param name: The name of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def email_id(self):
        """Gets the email_id of this JobDetailsHiringTeamList.  # noqa: E501

        Email ID of the team member.  # noqa: E501

        :return: The email_id of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this JobDetailsHiringTeamList.

        Email ID of the team member.  # noqa: E501

        :param email_id: The email_id of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    @property
    def id(self):
        """Gets the id of this JobDetailsHiringTeamList.  # noqa: E501

        Unique ID of the team member.  # noqa: E501

        :return: The id of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this JobDetailsHiringTeamList.

        Unique ID of the team member.  # noqa: E501

        :param id: The id of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def source(self):
        """Gets the source of this JobDetailsHiringTeamList.  # noqa: E501

        Source from where the team member was added.  # noqa: E501

        :return: The source of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this JobDetailsHiringTeamList.

        Source from where the team member was added.  # noqa: E501

        :param source: The source of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def type(self):
        """Gets the type of this JobDetailsHiringTeamList.  # noqa: E501

        Type of the team member.  # noqa: E501

        :return: The type of this JobDetailsHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this JobDetailsHiringTeamList.

        Type of the team member.  # noqa: E501

        :param type: The type of this JobDetailsHiringTeamList.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobDetailsHiringTeamList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDetailsHiringTeamList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
