# coding: utf-8

# flake8: noqa
"""
    employees-api-careerpath

    The Employee upskill APIs are related to the career pathing that an employee can use them for upskilling in an organisation.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.employeescareerpath.models.bad_request import BadRequest
from phenom.api.employeescareerpath.models.career_path_data import CareerPathData
from phenom.api.employeescareerpath.models.career_path_success_response import CareerPathSuccessResponse
from phenom.api.employeescareerpath.models.career_path_success_response_with_data import CareerPathSuccessResponseWithData
from phenom.api.employeescareerpath.models.create_career_path import CreateCareerPath
from phenom.api.employeescareerpath.models.current_job_profile import CurrentJobProfile
from phenom.api.employeescareerpath.models.empty import Empty
from phenom.api.employeescareerpath.models.error_response import ErrorResponse
from phenom.api.employeescareerpath.models.path_item import PathItem
from phenom.api.employeescareerpath.models.update_career_path import UpdateCareerPath
