# coding: utf-8

"""
    campaigns-email

    These APIs ensures an easy integration process of Email management for developers to send, read, and track Email campaigns within applications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmailCampaignActivityData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email_activity_id': 'str',
        'email': 'str',
        'event': 'str',
        'ip': 'str',
        'created_date': 'int',
        'useragent': 'str'
    }

    attribute_map = {
        'email_activity_id': 'emailActivityId',
        'email': 'email',
        'event': 'event',
        'ip': 'ip',
        'created_date': 'createdDate',
        'useragent': 'useragent'
    }

    def __init__(self, email_activity_id=None, email=None, event=None, ip=None, created_date=None, useragent=None):  # noqa: E501
        """EmailCampaignActivityData - a model defined in Swagger"""  # noqa: E501
        self._email_activity_id = None
        self._email = None
        self._event = None
        self._ip = None
        self._created_date = None
        self._useragent = None
        self.discriminator = None
        self.email_activity_id = email_activity_id
        self.email = email
        self.event = event
        self.ip = ip
        self.created_date = created_date
        self.useragent = useragent

    @property
    def email_activity_id(self):
        """Gets the email_activity_id of this EmailCampaignActivityData.  # noqa: E501

        Unique identifier for the email activity.  # noqa: E501

        :return: The email_activity_id of this EmailCampaignActivityData.  # noqa: E501
        :rtype: str
        """
        return self._email_activity_id

    @email_activity_id.setter
    def email_activity_id(self, email_activity_id):
        """Sets the email_activity_id of this EmailCampaignActivityData.

        Unique identifier for the email activity.  # noqa: E501

        :param email_activity_id: The email_activity_id of this EmailCampaignActivityData.  # noqa: E501
        :type: str
        """
        if email_activity_id is None:
            raise ValueError("Invalid value for `email_activity_id`, must not be `None`")  # noqa: E501

        self._email_activity_id = email_activity_id

    @property
    def email(self):
        """Gets the email of this EmailCampaignActivityData.  # noqa: E501

        Email address associated with the email campaign activity.  # noqa: E501

        :return: The email of this EmailCampaignActivityData.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this EmailCampaignActivityData.

        Email address associated with the email campaign activity.  # noqa: E501

        :param email: The email of this EmailCampaignActivityData.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def event(self):
        """Gets the event of this EmailCampaignActivityData.  # noqa: E501

        Event associated with email campaign activity.  # noqa: E501

        :return: The event of this EmailCampaignActivityData.  # noqa: E501
        :rtype: str
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this EmailCampaignActivityData.

        Event associated with email campaign activity.  # noqa: E501

        :param event: The event of this EmailCampaignActivityData.  # noqa: E501
        :type: str
        """
        if event is None:
            raise ValueError("Invalid value for `event`, must not be `None`")  # noqa: E501

        self._event = event

    @property
    def ip(self):
        """Gets the ip of this EmailCampaignActivityData.  # noqa: E501

        IP address associated with the email activity.  # noqa: E501

        :return: The ip of this EmailCampaignActivityData.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this EmailCampaignActivityData.

        IP address associated with the email activity.  # noqa: E501

        :param ip: The ip of this EmailCampaignActivityData.  # noqa: E501
        :type: str
        """
        if ip is None:
            raise ValueError("Invalid value for `ip`, must not be `None`")  # noqa: E501

        self._ip = ip

    @property
    def created_date(self):
        """Gets the created_date of this EmailCampaignActivityData.  # noqa: E501

        Timestamp indicating when the email activity was created.  # noqa: E501

        :return: The created_date of this EmailCampaignActivityData.  # noqa: E501
        :rtype: int
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this EmailCampaignActivityData.

        Timestamp indicating when the email activity was created.  # noqa: E501

        :param created_date: The created_date of this EmailCampaignActivityData.  # noqa: E501
        :type: int
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def useragent(self):
        """Gets the useragent of this EmailCampaignActivityData.  # noqa: E501

        User agent information associated with the email activity.  # noqa: E501

        :return: The useragent of this EmailCampaignActivityData.  # noqa: E501
        :rtype: str
        """
        return self._useragent

    @useragent.setter
    def useragent(self, useragent):
        """Sets the useragent of this EmailCampaignActivityData.

        User agent information associated with the email activity.  # noqa: E501

        :param useragent: The useragent of this EmailCampaignActivityData.  # noqa: E501
        :type: str
        """
        if useragent is None:
            raise ValueError("Invalid value for `useragent`, must not be `None`")  # noqa: E501

        self._useragent = useragent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmailCampaignActivityData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailCampaignActivityData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
