# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class AttachmentDataAttachments(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attachment_id': 'str',
        'attachment_name': 'str',
        'attachment_type': 'str'
    }

    attribute_map = {
        'attachment_id': 'attachmentId',
        'attachment_name': 'attachmentName',
        'attachment_type': 'attachmentType'
    }

    def __init__(self, attachment_id=None, attachment_name=None, attachment_type=None):  # noqa: E501
        """AttachmentDataAttachments - a model defined in Swagger"""  # noqa: E501
        self._attachment_id = None
        self._attachment_name = None
        self._attachment_type = None
        self.discriminator = None
        if attachment_id is not None:
            self.attachment_id = attachment_id
        if attachment_name is not None:
            self.attachment_name = attachment_name
        if attachment_type is not None:
            self.attachment_type = attachment_type

    @property
    def attachment_id(self):
        """Gets the attachment_id of this AttachmentDataAttachments.  # noqa: E501

        Unique identifier for the attachment.  # noqa: E501

        :return: The attachment_id of this AttachmentDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this AttachmentDataAttachments.

        Unique identifier for the attachment.  # noqa: E501

        :param attachment_id: The attachment_id of this AttachmentDataAttachments.  # noqa: E501
        :type: str
        """

        self._attachment_id = attachment_id

    @property
    def attachment_name(self):
        """Gets the attachment_name of this AttachmentDataAttachments.  # noqa: E501

        Name of the attachment.  # noqa: E501

        :return: The attachment_name of this AttachmentDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._attachment_name

    @attachment_name.setter
    def attachment_name(self, attachment_name):
        """Sets the attachment_name of this AttachmentDataAttachments.

        Name of the attachment.  # noqa: E501

        :param attachment_name: The attachment_name of this AttachmentDataAttachments.  # noqa: E501
        :type: str
        """

        self._attachment_name = attachment_name

    @property
    def attachment_type(self):
        """Gets the attachment_type of this AttachmentDataAttachments.  # noqa: E501

        Type of the attachment.  # noqa: E501

        :return: The attachment_type of this AttachmentDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._attachment_type

    @attachment_type.setter
    def attachment_type(self, attachment_type):
        """Sets the attachment_type of this AttachmentDataAttachments.

        Type of the attachment.  # noqa: E501

        :param attachment_type: The attachment_type of this AttachmentDataAttachments.  # noqa: E501
        :type: str
        """

        self._attachment_type = attachment_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AttachmentDataAttachments, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachmentDataAttachments):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
