# coding: utf-8

"""
    employees-api

    The employee profile APIs are used to create, access, update and delete employee profile and preferences.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmployeePreference(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'interests': 'list[str]',
        'locations': 'list[str]'
    }

    attribute_map = {
        'interests': 'interests',
        'locations': 'locations'
    }

    def __init__(self, interests=None, locations=None):  # noqa: E501
        """EmployeePreference - a model defined in Swagger"""  # noqa: E501
        self._interests = None
        self._locations = None
        self.discriminator = None
        if interests is not None:
            self.interests = interests
        if locations is not None:
            self.locations = locations

    @property
    def interests(self):
        """Gets the interests of this EmployeePreference.  # noqa: E501

        The areas in which the employee is interested.  # noqa: E501

        :return: The interests of this EmployeePreference.  # noqa: E501
        :rtype: list[str]
        """
        return self._interests

    @interests.setter
    def interests(self, interests):
        """Sets the interests of this EmployeePreference.

        The areas in which the employee is interested.  # noqa: E501

        :param interests: The interests of this EmployeePreference.  # noqa: E501
        :type: list[str]
        """

        self._interests = interests

    @property
    def locations(self):
        """Gets the locations of this EmployeePreference.  # noqa: E501

        The locations in which the employee is interested.  # noqa: E501

        :return: The locations of this EmployeePreference.  # noqa: E501
        :rtype: list[str]
        """
        return self._locations

    @locations.setter
    def locations(self, locations):
        """Sets the locations of this EmployeePreference.

        The locations in which the employee is interested.  # noqa: E501

        :param locations: The locations of this EmployeePreference.  # noqa: E501
        :type: list[str]
        """

        self._locations = locations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmployeePreference, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmployeePreference):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
