# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidatesRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_from': 'float',
        'type': 'str',
        'sort_by': 'GetCandidatesRequestSortBy',
        'size': 'float',
        'status': 'str',
        'filters': 'list[GetCandidatesRequestFilters]'
    }

    attribute_map = {
        '_from': 'from',
        'type': 'type',
        'sort_by': 'sortBy',
        'size': 'size',
        'status': 'status',
        'filters': 'filters'
    }

    def __init__(self, _from=None, type=None, sort_by=None, size=None, status=None, filters=None):  # noqa: E501
        """GetCandidatesRequest - a model defined in Swagger"""  # noqa: E501
        self.__from = None
        self._type = None
        self._sort_by = None
        self._size = None
        self._status = None
        self._filters = None
        self.discriminator = None
        if _from is not None:
            self._from = _from
        if type is not None:
            self.type = type
        if sort_by is not None:
            self.sort_by = sort_by
        if size is not None:
            self.size = size
        if status is not None:
            self.status = status
        if filters is not None:
            self.filters = filters

    @property
    def _from(self):
        """Gets the _from of this GetCandidatesRequest.  # noqa: E501

        Number to fetch records from.  # noqa: E501

        :return: The _from of this GetCandidatesRequest.  # noqa: E501
        :rtype: float
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this GetCandidatesRequest.

        Number to fetch records from.  # noqa: E501

        :param _from: The _from of this GetCandidatesRequest.  # noqa: E501
        :type: float
        """

        self.__from = _from

    @property
    def type(self):
        """Gets the type of this GetCandidatesRequest.  # noqa: E501

        List or grid view of candidates.  # noqa: E501

        :return: The type of this GetCandidatesRequest.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GetCandidatesRequest.

        List or grid view of candidates.  # noqa: E501

        :param type: The type of this GetCandidatesRequest.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def sort_by(self):
        """Gets the sort_by of this GetCandidatesRequest.  # noqa: E501


        :return: The sort_by of this GetCandidatesRequest.  # noqa: E501
        :rtype: GetCandidatesRequestSortBy
        """
        return self._sort_by

    @sort_by.setter
    def sort_by(self, sort_by):
        """Sets the sort_by of this GetCandidatesRequest.


        :param sort_by: The sort_by of this GetCandidatesRequest.  # noqa: E501
        :type: GetCandidatesRequestSortBy
        """

        self._sort_by = sort_by

    @property
    def size(self):
        """Gets the size of this GetCandidatesRequest.  # noqa: E501

        Number of records to return.  # noqa: E501

        :return: The size of this GetCandidatesRequest.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this GetCandidatesRequest.

        Number of records to return.  # noqa: E501

        :param size: The size of this GetCandidatesRequest.  # noqa: E501
        :type: float
        """

        self._size = size

    @property
    def status(self):
        """Gets the status of this GetCandidatesRequest.  # noqa: E501

        Different stages in Hiring Hierarchy.  # noqa: E501

        :return: The status of this GetCandidatesRequest.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetCandidatesRequest.

        Different stages in Hiring Hierarchy.  # noqa: E501

        :param status: The status of this GetCandidatesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["PROFILE_REVIEW", "READY_FOR_INTERVIEW", "EVALUATION", "REVIEW_PENDING", "EVALUATE_PENDING", "WAITING_FOR_OFFER_DECISION", "OFFER_PENDING", "OFFER_PROCEED", "HIRED", "REJECTED", "ALL"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def filters(self):
        """Gets the filters of this GetCandidatesRequest.  # noqa: E501

        Criteria for filtering the candidates.  # noqa: E501

        :return: The filters of this GetCandidatesRequest.  # noqa: E501
        :rtype: list[GetCandidatesRequestFilters]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this GetCandidatesRequest.

        Criteria for filtering the candidates.  # noqa: E501

        :param filters: The filters of this GetCandidatesRequest.  # noqa: E501
        :type: list[GetCandidatesRequestFilters]
        """

        self._filters = filters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidatesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidatesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
